@@ -3,5 +3,5 @@
 ARLIB	   = libg++-ar.a
 SHLINK     = libg++.a
 BUILD_LIBS = $(ARLIB) $(SHLIB) $(SHLINK)
-LIBS       = -L./$(TOLIBGXX) -L./$(TOLIBGXX)../libstdc++ -lg++ -lstdc++
-SHDEPS     = -L$${rootme}../libstdc++ -lstdc++ -lm -lcurses
+SHDEPS     = ../libstdc++/libstdc++.a -lm $(SHCURSES)
+SHCURSES   = -lcurses
