@@ -1164,7 +1164,8 @@ String common_prefix(const String& x, const String& y, int startpos)
   const char* topx = &(xchars[x.length()]);
   const char* ys = &(ychars[startpos]);
   const char* topy = &(ychars[y.length()]);
-  for (int l = 0; xs < topx && ys < topy && *xs++ == *ys++; ++l);
+  int l;
+  for (int l; xs < topx && ys < topy && *xs++ == *ys++; ++l);
   r.rep = Salloc(r.rep, ss, l, l);
   return r;
 }
@@ -1178,7 +1179,8 @@ String common_suffix(const String& x, const String& y, int startpos)
   const char* botx = xchars;
   const char* ys = &(ychars[y.length() + startpos]);
   const char* boty = ychars;
-  for (int l = 0; xs >= botx && ys >= boty && *xs == *ys ; --xs, --ys, ++l);
+  int l;
+  for (int l; xs >= botx && ys >= boty && *xs == *ys ; --xs, --ys, ++l);
   r.rep = Salloc(r.rep, ++xs, l, l);
   return r;
 }
