@@ -13,21 +13,19 @@ implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU Library General Public License for more details.
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-
 #ifndef _std_h
 #define _std_h 1
 
 #include <_G_config.h>
-#include <stddef.h>
-#include <stdlib.h>
-#include <string.h>
-#include <memory.h>
+#include <stddef>
+#include <cstdlib>
+#include <cstring>
 #include <unistd.h>
-#include <stdio.h> 
-#include <errno.h>
+#include <cstdio> 
+#include <cerrno>
 #include <fcntl.h>
 
 extern "C" {
