@@ -2,11 +2,12 @@
 #if _G_HAVE_ATEXIT
 #include <stdlib.h>
 
-typedef void (*voidfunc) _PARAMS((void));
+typedef void (*voidfunc) __P((void));
 
-static void _IO_register_cleanup ()
+static void
+DEFUN_VOID(_IO_register_cleanup)
 {
-  atexit ((voidfunc)_IO_flush_all);
+  atexit ((voidfunc)_IO_cleanup);
   _IO_cleanup_registration_needed = 0;
 }
 
