@@ -13,8 +13,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU CC; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+along with this library; see the file COPYING.  If not, write to the Free
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 As a special exception, if you link this library with files
 compiled with a GNU compiler to produce an executable, this does not cause
@@ -44,12 +44,12 @@ indirectbuf::~indirectbuf()
     if (_delete_flags & ios::out)  delete put_stream();
 }
 
-int indirectbuf::xsputn(const char* s, int n)
+streamsize indirectbuf::xsputn(const char* s, streamsize n)
 {
     return put_stream()->sputn(s, n);
 }
 
-int indirectbuf::xsgetn(char* s, int n)
+streamsize indirectbuf::xsgetn(char* s, streamsize n)
 {
     return get_stream()->sgetn(s, n);
 }
@@ -71,8 +71,8 @@ streampos indirectbuf::seekoff(streamoff off, _seek_dir dir, int mode)
 {
     int ret_val = 0;
     int select = mode == 0 ? (ios::in|ios::out) : mode;
-    streambuf *gbuf = (select & ios::in) ? get_stream() : NULL;
-    streambuf *pbuf = (select & ios::out) ? put_stream() : NULL;
+    streambuf *gbuf = (select & ios::in) ? get_stream() : (streambuf*)NULL;
+    streambuf *pbuf = (select & ios::out) ? put_stream() : (streambuf*)NULL;
     if (gbuf == pbuf)
 	ret_val = gbuf->seekoff(off, dir, mode);
     else {
@@ -88,8 +88,8 @@ streampos indirectbuf::seekpos(streampos pos, int mode)
 {
     int ret_val = EOF;
     int select = mode == 0 ? (ios::in|ios::out) : mode;
-    streambuf *gbuf = (select & ios::in) ? get_stream() : NULL;
-    streambuf *pbuf = (select & ios::out) ? put_stream() : NULL;
+    streambuf *gbuf = (select & ios::in) ? get_stream() : (streambuf*)NULL;
+    streambuf *pbuf = (select & ios::out) ? put_stream() : (streambuf*)NULL;
     if (gbuf == pbuf)
 	ret_val = gbuf->seekpos(pos, mode);
     else {
